@@ -265,6 +265,8 @@ MYFLT MOD(MYFLT a, MYFLT bb)
       MYFLT d = FMOD(a, b);
       while (d>b) d -= b;
       while (-d>b) d += b;
+      if (d>=b || d<0)
+        printf("**** a,b = %f, %f => D %f\n", a,b, d);
       return d;
   }
 }
@@ -2219,11 +2221,63 @@ int32_t subinak(CSOUND *csound, ASSIGN *p)
     return OK;
 }
 
+/**
+ * Identifies both signaling NaN (sNaN) and quiet NaN (qNaN).
+ * 
+ * According to the IEEE 754 standard, all NaN have the sign bit set to 0 and 
+ * all exponent bits set to 1. qNaN has the most significant bit of the
+ * fractional set to 1, while sNaN has most the significant bit of the 
+ * fraction set to 0 -- but the NEXT most significant bit of the fraction must 
+ * be set to 1! This is necessary in order to distinguish sNaN from positive 
+ * infinity. Hence, there are 2 bit masks to test. Doubles have the most 
+ * significant bit of the fraction in (0-based) bit 52, floats have the most 
+ * significant bit of the fraction in bit 22.
+ * double qNaN:
+ * 0111111111110000000000000000000000000000000000000000000000000000
+ * 0x7FF0000000000000ULL
+ * double sNaN:
+ * 0111111111101000000000000000000000000000000000000000000000000000
+ * 0x7FE8000000000000ULL
+ * float qNaN:
+ * 01111111110000000000000000000000  
+ * 0x7FC00000
+ * float sNaN:
+ * 01111111101000000000000000000000  
+ * 0x7FA00000
+ * NOTE: Not all compilers permit type casting a type-punned pointer. So, we 
+ * must explicitly copy rather than assign the data to test.
+ */
+static inline int _isnan(MYFLT x) {
+    #ifdef USE_DOUBLE
+        uint64_t bits;
+        memcpy(&bits, &x, sizeof(MYFLT));
+        if ((bits & 0x7FF0000000000000ULL) == 0x7FF0000000000000ULL) {
+            return 1;
+        } 
+        if ((bits & 0x7FE8000000000000ULL) == 0x7FE8000000000000ULL) {
+            return 1;
+        } 
+        return 0;
+    #else
+        uint32_t bits;
+        memcpy(&bits, &x, sizeof(MYFLT));
+        if ((bits & 0x7FC00000) == 0x7FC00000) {
+            return 1;
+        } 
+        if ((bits & 0x7FA00000) == 0x7FA00000) {
+            return 1;
+        } 
+        return 0;
+    #endif
+ }
+
+
 int32_t is_NaN(CSOUND *csound, ASSIGN *p)
 {
     IGN(csound);
-    *p->r = isnan(*p->a);
-    return OK;
+    // *p->r = isnan(*p->a);
+    *p->r = _isnan(*p->a);
+	return OK;
 }
 
 /* ********COULD BE IMPROVED******** */
@@ -2236,7 +2290,8 @@ int32_t is_NaNa(CSOUND *csound, ASSIGN *p)
     MYFLT *a = p->a;
     *p->r = FL(0.0);
     for (k=offset; k<early; k++)
-      *p->r += isnan(a[k]);
+      // *p->r += isnan(a[k]);
+      *p->r += _isnan(a[k]);
     return OK;
 }
 
